aboutsummaryrefslogtreecommitdiffstats
path: root/host/lib/include/uhdlib/usrp/cores
diff options
context:
space:
mode:
Diffstat (limited to 'host/lib/include/uhdlib/usrp/cores')
-rw-r--r--host/lib/include/uhdlib/usrp/cores/dsp_core_utils.hpp15
1 files changed, 9 insertions, 6 deletions
diff --git a/host/lib/include/uhdlib/usrp/cores/dsp_core_utils.hpp b/host/lib/include/uhdlib/usrp/cores/dsp_core_utils.hpp
index 74b4c3848..6371eb2e5 100644
--- a/host/lib/include/uhdlib/usrp/cores/dsp_core_utils.hpp
+++ b/host/lib/include/uhdlib/usrp/cores/dsp_core_utils.hpp
@@ -9,16 +9,19 @@
#include <tuple>
/*! For a requested frequency and sampling rate, return the
* correct frequency word (to set the CORDIC) and the actual frequency.
*/
void get_freq_and_freq_word(const double requested_freq,
const double tick_rate,
double& actual_freq,
- int32_t& freq_word);
+ int32_t& freq_word,
+ int word_width = 32);
-/*! For a requested frequency and sampling rate, return the
- * correct frequency word (to set the CORDIC) and the actual frequency.
+/*! For a requested frequency, sampling rate, and frequency word width (in
+ * number of bits), return the correct frequency word (to set the CORDIC or
+ * DDS) and the actual frequency.
*/
std::tuple<double, int> get_freq_and_freq_word(
- const double requested_freq, const double tick_rate);
+ const double requested_freq, const double tick_rate, int word_width = 32);
@@ -9,16 +9,19 @@
#include <tuple>
-/*! For a requested frequency and sampling rate, return the
- * correct frequency word (to set the CORDIC) and the actual frequency.
+/*! For a requested frequency, sampling rate, and frequency word width (in
+ * number of bits), return the correct frequency word (to set the CORDIC or
+ * DDS) and the actual frequency.
*/
void get_freq_and_freq_word(const double requested_freq,